@@ -3,8 +3,9 @@ Main interface for ds service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ds import (
+    from mypy_boto3_ds import (
         Client,
         DescribeDirectoriesPaginator,
         DescribeDomainControllersPaginator,
@@ -16,7 +17,7 @@ Usage::
         ListLogSubscriptionsPaginator,
         ListSchemaExtensionsPaginator,
         ListTagsForResourcePaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -32,8 +33,9 @@ Usage::
     list_log_subscriptions_paginator: ListLogSubscriptionsPaginator = client.get_paginator("list_log_subscriptions")
     list_schema_extensions_paginator: ListSchemaExtensionsPaginator = client.get_paginator("list_schema_extensions")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
+    ```
 """
-from mypy_boto3_ds.client import DirectoryServiceClient as Client, DirectoryServiceClient
+from mypy_boto3_ds.client import DirectoryServiceClient
 from mypy_boto3_ds.paginator import (
     DescribeDirectoriesPaginator,
     DescribeDomainControllersPaginator,
@@ -46,6 +48,8 @@ from mypy_boto3_ds.paginator import (
     ListTagsForResourcePaginator,
 )
 
+Client = DirectoryServiceClient
+
 
 __all__ = (
     "Client",
